@@ -372,7 +372,7 @@ typedef struct gpuSurfaceMappingInfo                *nvgpuSurfaceMapInfo_t;
 typedef struct UvmGpuP2PCapsParams_tag              *nvgpuP2PCapsParams_t;
 typedef struct gpuVaAllocInfo                       *nvgpuVaAllocInfo_t;
 typedef struct gpuMapInfo                           *nvgpuMapInfo_t;
-typedef struct gpuFbInfo                            *nvgpuFbInfo_t;
+typedef struct UvmGpuFbInfo_tag                     *nvgpuFbInfo_t;
 typedef struct UvmGpuFaultInfo_tag                  *nvgpuFaultInfo_t;
 typedef struct UvmGpuAccessCntrInfo_tag             *nvgpuAccessCntrInfo_t;
 typedef struct UvmGpuInfo_tag                       *nvgpuInfo_t;
