@@ -711,12 +711,13 @@ BOOL NV_API_CALL os_iommu_is_snooping_enabled(void)
     return TRUE;
 }
 
-NV_STATUS NV_API_CALL os_get_screen_info(
+void NV_API_CALL os_get_screen_info(
     NvU64 *pPhysicalAddress,
     NvU64 *pFbSize
 )
 {
-    return NV_ERR_NOT_SUPPORTED;
+    *pPhysicalAddress = 0;
+    *pFbSize = 0;
 }
 
 void NV_API_CALL os_register_compatible_ioctl(
