@@ -313,6 +313,7 @@ void nvidia_intr(void *xsc)
     nv_state_t *nv;
     NvU32 run_bottom_half = 0;
     nvidia_stack_t *sp;
+    NvU32 faultsCopied = 0;
 
     sc = (struct nvidia_softc *) xsc;
     nv = sc->nv_state;
@@ -326,6 +327,14 @@ void nvidia_intr(void *xsc)
     rm_isr(sp, nv, &run_bottom_half);
 
     if (run_bottom_half) {
+        /* 
+         * As UVM with faulting is currently not supported in this plateform, we can copy
+         * MMU faults after grabbing RM lock. With UVM, this routine should be called
+         * before calling rm_isr and bottom_half should be scheduled unconditionally
+         * with low priority thread as bottom_half can wait for lock
+         */
+        rm_gpu_copy_mmu_faults(sp, nv, &faultsCopied);
+
         /* We're not executing in an HW ISR context */
         rm_isr_bh(sp, nv);
     }
@@ -1584,17 +1593,6 @@ NV_STATUS NV_API_CALL nv_log_error(
     return NV_OK;
 }
 
-NV_STATUS NV_API_CALL nv_alloc_os_descriptor_handle(
-    nv_state_t *nv,
-    NvS32       fd,
-    void       *private,
-    NvU64       num_pages,
-    NvU32      *handle
-)
-{
-    return NV_ERR_NOT_SUPPORTED;
-}
-
 NvU64 NV_API_CALL nv_get_dma_start_address(
     nv_state_t *nv
 )
