@@ -151,7 +151,7 @@ NvBool      NV_API_CALL  os_is_xen_dom0              (void);
 NvBool      NV_API_CALL  os_is_vgx_hyper             (void);
 NV_STATUS   NV_API_CALL  os_inject_vgx_msi           (NvU16, NvU64, NvU32);
 NvBool      NV_API_CALL  os_is_grid_supported        (void);
-NV_STATUS   NV_API_CALL  os_get_screen_info          (NvU64 *, NvU64 *);
+void        NV_API_CALL  os_get_screen_info          (NvU64 *, NvU64 *);
 void        NV_API_CALL  os_bug_check                (NvU32, const char *);
 NV_STATUS   NV_API_CALL  os_lock_user_pages          (void *, NvU64, void **);
 NV_STATUS   NV_API_CALL  os_lookup_user_io_memory    (void *, NvU64, NvU64 **);
